@@ -131,7 +131,7 @@ panel_launcher_save_ditem (GnomeDesktopItem *ditem,
 	gnome_desktop_item_save (ditem, NULL, TRUE, &error);
 	if (error) {
 		panel_error_dialog (screen,
-				    "cannot_save_launcher",
+				    "cannot_save_launcher", TRUE,
 				    _("Cannot save launcher to disk"),
 				    "%s",
 				    error->message);
@@ -161,7 +161,7 @@ launch_url (Launcher *launcher)
 		GtkWidget *error_dialog;
 
 		error_dialog = panel_error_dialog (screen,
-						   "no_url_dialog",
+						   "no_url_dialog", TRUE,
 						   _("Cannot launch icon"),
 						   _("This launch icon does not specify a url to show."));
 		launcher_register_error_dialog (launcher, error_dialog);
@@ -174,6 +174,7 @@ launch_url (Launcher *launcher)
 	
 		error_dialog = panel_error_dialog (screen,
 						   "cannot_show_url_dialog",
+						   TRUE,
 						   _("Cannot show %s"),
 						   "%s",
 						   url,
@@ -183,9 +184,9 @@ launch_url (Launcher *launcher)
 	}
 }
 
-static void
-launch_cb (GtkWidget *widget,
-	   Launcher  *launcher)
+void
+launcher_launch (Launcher  *launcher,
+		 GtkWidget *widget)
 {
 	GnomeDesktopItem *item;
 
@@ -210,6 +211,7 @@ launch_cb (GtkWidget *widget,
 
 			error_dialog = panel_error_dialog (launcher_get_screen (launcher),
 							   "cannot_launch_icon",
+							   TRUE,
 							   _("Cannot launch icon"),
 							   "%s",
 							   error->message);
@@ -220,11 +222,20 @@ launch_cb (GtkWidget *widget,
 	
 	if (panel_global_config_get_drawer_auto_close ()) {
 		PanelToplevel *toplevel;
+		PanelToplevel *parent;
 
 		toplevel = PANEL_WIDGET (launcher->button->parent)->toplevel;
 
-		if (panel_toplevel_get_is_attached (toplevel)) 
+		if (panel_toplevel_get_is_attached (toplevel)) {
+			parent = panel_toplevel_get_attach_toplevel (toplevel);
+
+			while (panel_toplevel_get_is_attached (parent)) {
+				toplevel = parent;
+				parent = panel_toplevel_get_attach_toplevel (toplevel);
+			}
+
 			panel_toplevel_hide (toplevel, FALSE, -1);
+		}
 	}
 }
 
@@ -244,6 +255,9 @@ drag_data_received_cb (GtkWidget        *widget,
 
 	envp = panel_make_environment_for_screen (screen, NULL);
 
+	if (panel_global_config_get_enable_animations ())
+		xstuff_zoom_animate (widget, NULL);
+	
 	gnome_desktop_item_drop_uri_list_with_env (launcher->ditem,
 						   (const char *)selection_data->data,
 						   0 /* flags */,
@@ -254,7 +268,7 @@ drag_data_received_cb (GtkWidget        *widget,
 	if (error) {
 		GtkWidget *error_dialog;
 		error_dialog = panel_error_dialog (launcher_get_screen (launcher),
-						   "cannot_launch_icon",
+						   "cannot_launch_icon", TRUE,
 						   _("Cannot launch icon"),
 						   "%s",
 						   error->message);
@@ -506,8 +520,8 @@ create_launcher (const char *location)
 			   G_CALLBACK (drag_drop_cb), launcher);
 	g_signal_connect (launcher->button, "drag_leave",
 			   G_CALLBACK (drag_leave_cb), launcher);
-	g_signal_connect (launcher->button, "clicked",
-			  G_CALLBACK (launch_cb), launcher);
+	g_signal_connect_swapped (launcher->button, "clicked",
+				  G_CALLBACK (launcher_launch), launcher);
 
 	launcher->destroy_handler =
 			g_signal_connect (launcher->button, "destroy",
@@ -814,6 +828,12 @@ load_launcher_applet (const char       *location,
 	if (!launcher->info)
 		return NULL;
 
+	panel_applet_add_callback (launcher->info,
+				   "launch",
+				   GTK_STOCK_EXECUTE,
+				   _("_Launch"),
+				   NULL);
+
 	panel_applet_add_callback (launcher->info,
 				   "properties",
 				   GTK_STOCK_PROPERTIES,
@@ -942,12 +962,13 @@ really_add_launcher (GtkWidget *dialog, int response, gpointer data)
 		if (string_empty (gnome_desktop_item_get_localestring (ditem, GNOME_DESKTOP_ITEM_NAME))) {
 			err_dialog = panel_error_dialog (gtk_window_get_screen (GTK_WINDOW (dialog)),
 						         "cannot_create_launcher",
+							 TRUE,
 						         _("Cannot create launcher"),
 						         _("You have to specify a name."));
-			g_signal_connect_swapped (G_OBJECT (err_dialog),
+			g_signal_connect_swapped (G_OBJECT (dialog),
 						  "destroy",
-						   G_CALLBACK (panel_pop_window_busy),
-						   G_OBJECT (dialog));
+						   G_CALLBACK (gtk_widget_destroy),
+						   G_OBJECT (err_dialog));
 			return;
 		}
 		
@@ -959,12 +980,13 @@ really_add_launcher (GtkWidget *dialog, int response, gpointer data)
 		     string_empty (gnome_desktop_item_get_string (ditem, GNOME_DESKTOP_ITEM_URL)))) {
 			err_dialog = panel_error_dialog (gtk_window_get_screen (GTK_WINDOW (dialog)),
 							 "cannot_create_launcher",
+							 TRUE,
 							 _("Cannot create launcher"),
 							 _("You have to specify a valid URL or command."));
-			g_signal_connect_swapped (G_OBJECT (err_dialog),
+			g_signal_connect_swapped (G_OBJECT (dialog),
 						  "destroy",
-						  G_CALLBACK (panel_pop_window_busy),
-						  G_OBJECT (dialog));
+						  G_CALLBACK (gtk_widget_destroy),
+						  G_OBJECT (err_dialog));
 			return;
 		}
 
